#
# spec file for package python-testflo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-testflo
Version:        1.4.15
Release:        1.6
Summary:        A flow-based testing framework
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/OpenMDAO/testflo
Source:         https://files.pythonhosted.org/packages/source/t/testflo/testflo-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(preun):update-alternatives
Recommends:     python-coverage
Recommends:     python-mpi4py
Recommends:     python-psutil
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module mpi4py}
BuildRequires:  %{python_module psutil}
# /SECTION
%python_subpackages

%description
This module provides a flow-based testing framework. testflo supports
testing of the OpenMDAO framework. Some OpenMDAO features require
execution under MPI, while others don't. testflo runs all of the
authors' tests in the same way and allows them to build their tests
using unittest.TestCase objects that they are familiar with.

%prep
%setup -q -n testflo-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/testflo

# Tests not included in sdists
# %%check
# %%python_expand $python -B -m unittest testflo.test

%post
%python_install_alternative testflo

%postun
%python_uninstall_alternative testflo

%files %{python_files}
%license LICENSE.txt
%doc README.md
%python_alternative %{_bindir}/testflo
%{python_sitelib}/testflo
%{python_sitelib}/testflo-%{version}.dist-info

%changelog
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.15:
  * handle python 3.12.1 change to skip behavior
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.14:
  * Fix bug with `disallow_skipped` option
* Fri Nov 11 2022 pgajdos@suse.com
- silent rpmlint
* Fri Nov 11 2022 pgajdos@suse.com
- python-six is not required
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.4.9
  * added --durations option and fixed some config file issues #71
  * added --durations option that prints the n longest running tests (similar to pytest)
  * fixed the way the .testflo config file is processed so it should support setting any, or at least most of the command line options
  * added the --skip_dirs command line option (skip_dirs could be defined in the config file but it wasn't a valid command line option)
* Wed Jul 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- - Skip python 3.6 because numpy no longer support it.
* Fri Jul 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.4.2
  * support Python 3.6, 3.7 and 3.8
  * added option to exclude test function
  * dropped RELEASE_NOTES.txt -- there is no upstream changelog by now
* Wed Mar 11 2020 pgajdos@suse.com
- version update to 1.4.1
  * bugfix
- deleted patches
  - use_setuptools.patch (upstreamed)
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to testflo version 1.3.4
  * bug fix
- Update to testflo version 1.3.3
  * bug fix
- Update to testflo version 1.3.2
  * added support for ISOLATED attribute
- Update to testflo version 1.3.1
  Aug 17, 2018
  * output from --pre_announce now looks better, with the result ('.', 'S', or 'F') showing on the same line as the
    "about to run ..." instead of on the following line
  * comments are now allowed inside of a test list file
  * added a --full_path option so that full testspec paths will be displayed. Having the full path make it easier to
    copy and paste the testspec to run testflo on just that single test.
  * updated the long_description in setup.py for pypi.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Trim history lesson from description. Rewrite description so
  it is from the perspective of openSUSE, not upstream.
* Thu May 24 2018 toddrme2178@gmail.com
- Add license
- spec file cleanups
* Wed May 24 2017 toddrme2178@gmail.com
- Initial version
- Add use_setuptools.patch to make sure entrypoints are installed
